==> bigtree-0.18.1.tar.gz: bigtree-0.18.1/docs/index.md <==
---
title: bigtree
description: Tree Implementation and Methods for Python, integrated with list, dictionary, pandas and polars DataFrame.
hide:
  - toc
---

# 🌳 Documentation

[![python-version](https://badge.fury.io/py/bigtree.svg "python-version")](https://badge.fury.io/py/bigtree)
[![python-compatibility](https://img.shields.io/pypi/pyversions/bigtree.svg "python-compatibility")](https://pypi.python.org/pypi/bigtree)
[![Documentation Status](https://readthedocs.org/projects/bigtree/badge/?version=latest "Documentation Status")](https://bigtree.readthedocs.io/en/latest/?badge=latest)
[![code-coverage](https://codecov.io/github/kayjan/bigtree/branch/master/graph/badge.svg?token=O5gyTsGIiw "code-coverage")](https://codecov.io/gh/kayjan/bigtree)
[![github-workflows](https://github.com/kayjan/bigtree/actions/workflows/pytest.yml/badge.svg "github-workflows")](https://github.com/kayjan/bigtree/actions/workflows/pytest.yml)
![license](https://img.shields.io/static/v1?label=license&message=MIT&color=blue "license")
![black](https://img.shields.io/static/v1?label=style&message=black&color=black "black")

Tree Implementation and Methods for Python, integrated with list, dictionary, pandas and polars DataFrame.

It is pythonic, making it easy to learn and extendable to many types of workflows.

<div class="grid cards" markdown>

- :material-clock-fast:{ .lg .middle } __Set up in 2 minutes__

    ---
    Install [`bigtree`](#) with `pip` or `conda` and get up
    and running in minutes

    [:octicons-arrow-right-24: Getting started](install.md)

- :material-map:{ .lg .middle } __Getting started__

    ---
    View demonstration on how to use [`bigtree`](#)

    [:octicons-arrow-right-24: Reference](demo/index.md)

- :material-newspaper-variant-outline:{ .lg .middle } __Resources__

    ---
    Articles relating to trees and [`bigtree`](#)

    [:octicons-arrow-right-24: View articles](resources/articles.md)

- :material-heart-outline:{ .lg .middle } __Support bigtree__

    ---
    Do support if you like this project!

    [:octicons-arrow-right-24: Support me](https://www.buymeacoffee.com/kayjan)

</div>

-----

Related Links:

- Community: [Issues](https://github.com/kayjan/bigtree/issues) / [Discussions](https://github.com/kayjan/bigtree/discussions)
- Package: [PyPI](https://pypi.org/project/bigtree/) / [Conda](https://anaconda.org/conda-forge/bigtree)

==> bigtree-0.18.3.tar.gz: bigtree-0.18.3/docs/index.md <==
---
title: bigtree
description: Tree Implementation and Methods for Python, integrated with list, dictionary, pandas and polars DataFrame.
hide:
  - toc
---

# 🌳 Documentation

[![python-version](https://badge.fury.io/py/bigtree.svg "python-version")](https://badge.fury.io/py/bigtree)
[![python-compatibility](https://img.shields.io/pypi/pyversions/bigtree.svg "python-compatibility")](https://pypi.python.org/pypi/bigtree)
[![Documentation Status](https://readthedocs.org/projects/bigtree/badge/?version=latest "Documentation Status")](https://bigtree.readthedocs.io/en/latest/?badge=latest)
[![code-coverage](https://codecov.io/github/kayjan/bigtree/branch/master/graph/badge.svg?token=O5gyTsGIiw "code-coverage")](https://codecov.io/gh/kayjan/bigtree)
[![github-workflows](https://github.com/kayjan/bigtree/actions/workflows/pytest.yml/badge.svg "github-workflows")](https://github.com/kayjan/bigtree/actions/workflows/pytest.yml)
![license](https://img.shields.io/static/v1?label=license&message=MIT&color=blue "license")
![black](https://img.shields.io/static/v1?label=style&message=black&color=black "black")

Tree Implementation and Methods for Python, integrated with list, dictionary, pandas and polars DataFrame.

It is pythonic, making it easy to learn and extendable to many types of workflows.

<div class="grid cards" markdown>

- :material-clock-fast:{ .lg .middle } __Set up in 2 minutes__

    ---
    Install [`bigtree`](#) with `pip` or `conda` and get up
    and running in minutes

    [:octicons-arrow-right-24: Getting started](home/install.md)

- :material-map:{ .lg .middle } __Getting started__

    ---
    View demonstration on how to use [`bigtree`](#)

    [:octicons-arrow-right-24: Reference](demo/tree.md)

- :material-newspaper-variant-outline:{ .lg .middle } __Resources__

    ---
    Articles relating to trees and [`bigtree`](#)

    [:octicons-arrow-right-24: View articles](resources/articles.md)

- :material-heart-outline:{ .lg .middle } __Support bigtree__

    ---
    Do support if you like this project!

    [:octicons-arrow-right-24: Support me](https://www.buymeacoffee.com/kayjan)

</div>

-----

Related Links:

- Community: [Issues](https://github.com/kayjan/bigtree/issues) / [Discussions](https://github.com/kayjan/bigtree/discussions)
- Package: [PyPI](https://pypi.org/project/bigtree/) / [Conda](https://anaconda.org/conda-forge/bigtree)
